@@ -60,18 +60,19 @@ import io
 from pathlib import Path
 from typing import List, Sequence, Tuple, Union
 
-from PyQt5.QtCore import Qt, QPoint, QSize, QEvent
-from PyQt5.QtWidgets \
+from PyQt6.QtCore import Qt, QPoint, QSize, QEvent
+from PyQt6.QtWidgets \
     import (QApplication, QMessageBox, QFileDialog, QDialog, QLineEdit, QLabel,
             QFormLayout, QVBoxLayout, QGroupBox, QDialogButtonBox, QSplitter,
             QTextBrowser, QCheckBox, QGridLayout, QLayout, QHBoxLayout,
             QPushButton, QWidget, QComboBox, QTableView, QAbstractItemView,
-            QPlainTextEdit, QToolBar, QMainWindow, QTabWidget, QInputDialog)
-from PyQt5.QtGui \
+            QPlainTextEdit, QToolBar, QMainWindow, QTabWidget, QInputDialog,
+            QComboBox)
+from PyQt6.QtGui \
     import (QIntValidator, QImageWriter, QStandardItemModel, QStandardItem,
             QValidator, QWheelEvent)
-from PyQt5.QtSvg import QSvgWidget
-from PyQt5.QtPrintSupport import (QPrintPreviewDialog, QPrintPreviewWidget,
+from PyQt6.QtSvgWidgets import QSvgWidget
+from PyQt6.QtPrintSupport import (QPrintPreviewDialog, QPrintPreviewWidget,
                                   QPrinter)
 
 try:
@@ -80,6 +81,17 @@ try:
 except ImportError:
     Figure = None
 
+try:
+    import openpyxl
+    import pycel
+except ImportError:
+    openpyxl = None
+
+try:
+    import moneyed
+except ImportError:
+    moneyed = None
+
 try:
     from pyspread.actions import ChartDialogActions
     from pyspread.toolbar import ChartTemplatesToolBar, RChartTemplatesToolBar
@@ -108,8 +120,9 @@ class DiscardChangesDialog:
 
     title = "Unsaved changes"
     text = "There are unsaved changes.\nDo you want to save?"
-    choices = QMessageBox.Discard | QMessageBox.Cancel | QMessageBox.Save
-    default_choice = QMessageBox.Save
+    buttons = QMessageBox.StandardButton
+    choices = buttons.Discard | buttons.Cancel | buttons.Save
+    default_choice = buttons.Save
 
     def __init__(self, main_window: QMainWindow):
         """
@@ -132,9 +145,9 @@ class DiscardChangesDialog:
         button_approval = QMessageBox.warning(self.main_window, self.title,
                                               self.text, self.choices,
                                               self.default_choice)
-        if button_approval == QMessageBox.Discard:
+        if button_approval == QMessageBox.StandardButton.Discard:
             return True
-        if button_approval == QMessageBox.Save:
+        if button_approval == QMessageBox.StandardButton.Save:
             return False
 
 
@@ -142,8 +155,9 @@ class DiscardDataDialog(DiscardChangesDialog):
     """Modal dialog that asks if the user wants to discard data"""
 
     title = "Data to be discarded"
-    choices = QMessageBox.Discard | QMessageBox.Cancel
-    default_choice = QMessageBox.Cancel
+    buttons = QMessageBox.StandardButton
+    choices = buttons.Discard | buttons.Cancel
+    default_choice = buttons.Cancel
 
     def __init__(self, main_window: QMainWindow, text: str):
         """
@@ -169,8 +183,9 @@ class ApproveWarningDialog:
             "It may harm your system as any program can. Please check all "
             "cells thoroughly before proceeding.\n \n"
             "Proceed and sign this file as trusted?")
-    choices = QMessageBox.No | QMessageBox.Yes
-    default_choice = QMessageBox.No
+    buttons = QMessageBox.StandardButton
+    choices = buttons.No | buttons.Yes
+    default_choice = buttons.No
 
     def __init__(self, parent: QWidget):
         """
@@ -193,9 +208,9 @@ class ApproveWarningDialog:
         button_approval = QMessageBox.warning(self.parent, self.title,
                                               self.text, self.choices,
                                               self.default_choice)
-        if button_approval == QMessageBox.Yes:
+        if button_approval == self.buttons.Yes:
             return True
-        if button_approval == QMessageBox.No:
+        if button_approval == self.buttons.No:
             return False
 
 
@@ -256,11 +271,18 @@ class DataEntryDialog(QDialog):
 
         """
 
-        result = self.exec_()
+        result = self.exec()
 
-        if result == QDialog.Accepted:
-            return tuple(editor.text() if isinstance(editor, QLineEdit)
-                         else editor.isChecked() for editor in self.editors)
+        if result == QDialog.DialogCode.Accepted:
+            data = []
+            for editor in self.editors:
+                if isinstance(editor, QLineEdit):
+                    data.append(editor.text())
+                elif isinstance(editor, QComboBox):
+                    data.append(editor.currentText())
+                else:
+                    data.append(editor.isChecked())
+            return tuple(data)
 
     def create_form(self) -> QGroupBox:
         """Returns form inside a QGroupBox"""
@@ -276,15 +298,19 @@ class DataEntryDialog(QDialog):
             if validator is bool:
                 editor = QCheckBox("")
                 editor.setChecked(initial_value)
+            elif hasattr(validator, "acceptable_values"):
+                editor = QComboBox()
+                editor.addItems(validator.acceptable_values)
+                editor.setCurrentText(initial_value)
             else:
                 editor = QLineEdit(str(initial_value))
-                editor.setAlignment(Qt.AlignRight)
+                editor.setAlignment(Qt.AlignmentFlag.AlignRight)
             if validator and validator is not bool:
                 editor.setValidator(validator)
             form_layout.addRow(QLabel(label + " :"), editor)
             self.editors.append(editor)
 
-        form_layout.setLabelAlignment(Qt.AlignRight)
+        form_layout.setLabelAlignment(Qt.AlignmentFlag.AlignRight)
         form_group_box.setLayout(form_layout)
 
         return form_group_box
@@ -292,8 +318,8 @@ class DataEntryDialog(QDialog):
     def create_buttonbox(self) -> QDialogButtonBox:
         """Returns a QDialogButtonBox with Ok and Cancel"""
 
-        button_box = QDialogButtonBox(QDialogButtonBox.Ok
-                                      | QDialogButtonBox.Cancel)
+        button_box = QDialogButtonBox(QDialogButtonBox.StandardButton.Ok
+                                      | QDialogButtonBox.StandardButton.Cancel)
         button_box.accepted.connect(self.accept)
         button_box.rejected.connect(self.reject)
 
@@ -493,6 +519,21 @@ class PrintAreaDialog(CsvExportAreaDialog):
         return bb_top, bb_left, bb_bottom, bb_right, table, table
 
 
+class TupleValidator(QValidator):
+    """Validator for a tuple of values, normally strings"""
+
+    def __init__(self, *acceptable_values):
+        super().__init__()
+        self.acceptable_values = acceptable_values
+
+    def validate(self, text, pos):
+        """Validator core function. Must be overloaded."""
+
+        if text in self.acceptable_values:
+            return self.State.Acceptable
+        return self.State.Invalid
+
+
 class PreferencesDialog(DataEntryDialog):
     """Modal dialog for entering pyspread preferences"""
 
@@ -510,10 +551,20 @@ class PreferencesDialog(DataEntryDialog):
         self.keys = ["signature_key", "timeout", "refresh_timeout",
                      "max_file_history", "show_statusbar_sum"]
         self.mappers = [str, int, int, int, bool]
+
+        int_validator = QIntValidator()
+        int_validator.setBottom(0)  # Do not allow negative values
+
+        validators = [None, int_validator, int_validator, int_validator, bool]
+        if moneyed is not None:
+            currencies = map(str, moneyed.list_all_currencies())
+            tuple_validator = TupleValidator(*currencies)
+            labels.append("Money default currency")
+            self.keys.append("currency_iso_code")
+            self.mappers.append(str)
+            validators.append(tuple_validator)
+
         data = [getattr(parent.settings, key) for key in self.keys]
-        validator = QIntValidator()
-        validator.setBottom(0)  # Do not allow negative values
-        validators = [None, validator, validator, validator, bool]
         super().__init__(parent, title, labels, data, groupbox_title,
                          validators)
 
@@ -594,8 +645,11 @@ class FileDialogBase:
 
     filters_list = [
         "Pyspread un-compressed (*.pysu)",
-        "Pyspread compressed (*.pys)"
+        "Pyspread compressed (*.pys)",
     ]
+    if openpyxl is not None:
+        filters_list.append("Office Open XML - Tabellendokument (*.xlsx)")
+
     selected_filter = None
 
     @property
@@ -608,9 +662,7 @@ class FileDialogBase:
     def suffix(self) -> str:
         """Suffix for filepath"""
 
-        if self.filters_list.index(self.selected_filter):
-            return ".pys"
-        return ".pysu"
+        return self.selected_filter.split("(")[-1].strip()[1:-1]
 
     def __init__(self, main_window: QMainWindow):
         """
@@ -810,11 +862,11 @@ class FindDialog(QDialog):
         self.regex_checkbox = QCheckBox("Regular e&xpression")
         self.from_start_checkbox = QCheckBox("From &start")
 
-        self.button_box = QDialogButtonBox(Qt.Vertical)
+        self.button_box = QDialogButtonBox(Qt.Orientation.Vertical)
         self.button_box.addButton(self.find_button,
-                                  QDialogButtonBox.ActionRole)
+                                  QDialogButtonBox.ButtonRole.ActionRole)
         self.button_box.addButton(self.more_button,
-                                  QDialogButtonBox.ActionRole)
+                                  QDialogButtonBox.ButtonRole.ActionRole)
 
     def _layout(self):
         """Find dialog layout"""
@@ -838,7 +890,7 @@ class FindDialog(QDialog):
         self.search_layout.addWidget(self.results_checkbox)
 
         self.main_layout = QGridLayout()
-        self.main_layout.setSizeConstraint(QLayout.SetFixedSize)
+        self.main_layout.setSizeConstraint(QLayout.SizeConstraint.SetFixedSize)
         self.main_layout.addLayout(self.search_layout, 0, 0)
         self.main_layout.addWidget(self.button_box, 0, 1)
         self.main_layout.addWidget(self.extension, 1, 0, 1, 2)
@@ -916,9 +968,9 @@ class ReplaceDialog(FindDialog):
         self.replace_all_button = QPushButton("Replace &all")
 
         self.button_box.addButton(self.replace_button,
-                                  QDialogButtonBox.ActionRole)
+                                  QDialogButtonBox.ButtonRole.ActionRole)
         self.button_box.addButton(self.replace_all_button,
-                                  QDialogButtonBox.ActionRole)
+                                  QDialogButtonBox.ButtonRole.ActionRole)
 
         self.setTabOrder(self.search_text_editor, self.replace_text_editor)
         self.setTabOrder(self.more_button, self.replace_button)
@@ -1068,12 +1120,13 @@ class ChartDialog(QDialog):
     def create_buttonbox(self):
         """Returns a QDialogButtonBox with Ok and Cancel"""
 
-        button_box = QDialogButtonBox(QDialogButtonBox.Ok
-                                      | QDialogButtonBox.Apply
-                                      | QDialogButtonBox.Cancel)
+        button_box = QDialogButtonBox(QDialogButtonBox.StandardButton.Ok
+                                      | QDialogButtonBox.StandardButton.Apply
+                                      | QDialogButtonBox.StandardButton.Cancel)
         button_box.accepted.connect(self.accept)
         button_box.rejected.connect(self.reject)
-        button_box.button(QDialogButtonBox.Apply).clicked.connect(self.apply)
+        button_box.button(
+            QDialogButtonBox.StandardButton.Apply).clicked.connect(self.apply)
         return button_box
 
 
@@ -1123,7 +1176,7 @@ class CsvParameterGroupBox(QGroupBox):
 
         super().__init__(parent)
         self.parent = parent
-        self.default_encoding = parent.csv_encoding
+        self.default_encoding = parent.parent.settings.default_encoding
         self.encodings = parent.parent.settings.encodings
 
         self.setTitle(self.title)
@@ -1218,8 +1271,8 @@ class CsvParameterGroupBox(QGroupBox):
         hbox_layout.addSpacing(20)
         hbox_layout.addLayout(right_form_layout)
 
-        left_form_layout.setLabelAlignment(Qt.AlignRight)
-        right_form_layout.setLabelAlignment(Qt.AlignRight)
+        left_form_layout.setLabelAlignment(Qt.AlignmentFlag.AlignRight)
+        right_form_layout.setLabelAlignment(Qt.AlignmentFlag.AlignRight)
 
         left_form_layout.addRow(self.encoding_label, self.encoding_widget)
         left_form_layout.addRow(self.quotechar_label, self.quotechar_widget)
@@ -1322,7 +1375,7 @@ class CsvTable(QTableView):
 
         self.model = QStandardItemModel(self)
         self.setModel(self.model)
-        self.setEditTriggers(QAbstractItemView.NoEditTriggers)
+        self.setEditTriggers(QAbstractItemView.EditTrigger.NoEditTriggers)
         self.verticalHeader().hide()
 
     def add_choice_row(self, length: int):
@@ -1452,15 +1505,17 @@ class CsvImportDialog(QDialog):
     def create_buttonbox(self):
         """Returns a QDialogButtonBox"""
 
-        button_box = QDialogButtonBox(QDialogButtonBox.Reset
-                                      | QDialogButtonBox.Apply
-                                      | QDialogButtonBox.Ok
-                                      | QDialogButtonBox.Cancel)
+        button_box = QDialogButtonBox(QDialogButtonBox.StandardButton.Reset
+                                      | QDialogButtonBox.StandardButton.Apply
+                                      | QDialogButtonBox.StandardButton.Ok
+                                      | QDialogButtonBox.StandardButton.Cancel)
 
         button_box.accepted.connect(self.accept)
         button_box.rejected.connect(self.reject)
-        button_box.button(QDialogButtonBox.Reset).clicked.connect(self.reset)
-        button_box.button(QDialogButtonBox.Apply).clicked.connect(self.apply)
+        button_box.button(
+            QDialogButtonBox.StandardButton.Reset).clicked.connect(self.reset)
+        button_box.button(
+            QDialogButtonBox.StandardButton.Apply).clicked.connect(self.apply)
 
         return button_box
 
@@ -1628,15 +1683,17 @@ class CsvExportDialog(QDialog):
     def create_buttonbox(self) -> QDialogButtonBox:
         """Returns button box with Reset, Apply, Ok, Cancel"""
 
-        button_box = QDialogButtonBox(QDialogButtonBox.Reset
-                                      | QDialogButtonBox.Apply
-                                      | QDialogButtonBox.Ok
-                                      | QDialogButtonBox.Cancel)
+        button_box = QDialogButtonBox(QDialogButtonBox.StandardButton.Reset
+                                      | QDialogButtonBox.StandardButton.Apply
+                                      | QDialogButtonBox.StandardButton.Ok
+                                      | QDialogButtonBox.StandardButton.Cancel)
 
         button_box.accepted.connect(self.accept)
         button_box.rejected.connect(self.reject)
-        button_box.button(QDialogButtonBox.Reset).clicked.connect(self.reset)
-        button_box.button(QDialogButtonBox.Apply).clicked.connect(self.apply)
+        button_box.button(
+            QDialogButtonBox.StandardButton.Reset).clicked.connect(self.reset)
+        button_box.button(
+            QDialogButtonBox.StandardButton.Apply).clicked.connect(self.apply)
 
         return button_box
 
@@ -1740,7 +1797,7 @@ class PrintPreviewDialog(QPrintPreviewDialog):
         """
 
         modifiers = QApplication.keyboardModifiers()
-        if modifiers == Qt.ControlModifier:
+        if modifiers == Qt.KeyboardModifier.ControlModifier:
             if event.angleDelta().y() > 0:
                 zoom_factor = self.widget.zoomFactor() / 1.1
             else:
