@@ -46,12 +46,12 @@ try:
     from PyQt6.QtSvgWidgets import QSvgWidget
 except ImportError:
     QSvgWidget = None
-from PyQt6.QtGui import QColor, QFont, QPalette, QPainter, QUndoStack
+from PyQt6.QtGui import QColor, QFont, QPainter, QUndoStack
 from PyQt6.QtPrintSupport import QPrinter, QPrintDialog
 
 try:
     from pyspread.__init__ import VERSION, APP_NAME
-    from pyspread.settings import Settings, WEB_URL
+    from pyspread.settings import Settings, WEB_URL, AUTHORS_PATH
     from pyspread.icons import Icon, IconPath
     from pyspread.grid import Grid, TableChoice
     from pyspread.grid_renderer import painter_save
@@ -73,7 +73,7 @@ try:
     from pyspread.model.model import CellAttributes
 except ImportError:
     from __init__ import VERSION, APP_NAME
-    from settings import Settings, WEB_URL
+    from settings import Settings, WEB_URL, AUTHORS_PATH
     from icons import Icon, IconPath
     from grid import Grid, TableChoice
     from grid_renderer import painter_save
@@ -720,7 +720,7 @@ class MainWindow(QMainWindow):
     def gen_authors(self):
         """Generator of authors from the AUTHORS file"""
 
-        with open(Path(__file__).parents[1] / "AUTHORS") as infile:
+        with open(AUTHORS_PATH) as infile:
             for line in infile:
                 if not line.strip():
                     break
